@@ -78,6 +78,19 @@ class NotificationBase(PluginBase):
         :param message: Message to process.
         """
 
+    @staticmethod
+    def _consume_and_drop(notifications):
+        """RPC endpoint for useless notification level"""
+        # NOTE(sileht): nothing special todo here, but because we listen
+        # for the generic notification exchange we have to consume all its
+        # queues
+
+    audit = _consume_and_drop
+    debug = _consume_and_drop
+    warn = _consume_and_drop
+    error = _consume_and_drop
+    critical = _consume_and_drop
+
     def info(self, notifications):
         """RPC endpoint for notification messages at info level
 
