@@ -22,11 +22,9 @@ from paste import deploy
 import pecan
 from werkzeug import serving
 
-from ceilometer.api import config as api_config
 from ceilometer.api import hooks
 from ceilometer.api import middleware
-from ceilometer.i18n import _
-from ceilometer.i18n import _LW
+from ceilometer.i18n import _LI, _LW
 
 LOG = log.getLogger(__name__)
 
@@ -54,23 +52,19 @@ CONF.register_opts(OPTS)
 CONF.register_opts(API_OPTS, group='api')
 
 
-def get_pecan_config():
-    # Set up the pecan configuration
-    filename = api_config.__file__.replace('.pyc', '.py')
-    return pecan.configuration.conf_from_file(filename)
-
-
-def setup_app(pecan_config=None, extra_hooks=None):
+def setup_app(pecan_config=None):
     # FIXME: Replace DBHook with a hooks.TransactionHook
     app_hooks = [hooks.ConfigHook(),
                  hooks.DBHook(),
                  hooks.NotifierHook(),
                  hooks.TranslationHook()]
-    if extra_hooks:
-        app_hooks.extend(extra_hooks)
 
-    if not pecan_config:
-        pecan_config = get_pecan_config()
+    pecan_config = pecan_config or {
+        "app": {
+            'root': 'ceilometer.api.controllers.root.RootController',
+            'modules': ['ceilometer.api'],
+        }
+    }
 
     pecan.configuration.set_config(dict(pecan_config), overwrite=True)
 
@@ -82,9 +76,8 @@ def setup_app(pecan_config=None, extra_hooks=None):
                         'the value is overrided with False'))
 
     app = pecan.make_app(
-        pecan_config.app.root,
+        pecan_config['app']['root'],
         debug=pecan_debug,
-        force_canonical=getattr(pecan_config.app, 'force_canonical', True),
         hooks=app_hooks,
         wrap_app=middleware.ParsableErrorMiddleware,
         guess_content_type_from_ext=False
@@ -93,23 +86,6 @@ def setup_app(pecan_config=None, extra_hooks=None):
     return app
 
 
-class VersionSelectorApplication(object):
-    def __init__(self):
-        pc = get_pecan_config()
-
-        def not_found(environ, start_response):
-            start_response('404 Not Found', [])
-            return []
-
-        self.v1 = not_found
-        self.v2 = setup_app(pecan_config=pc)
-
-    def __call__(self, environ, start_response):
-        if environ['PATH_INFO'].startswith('/v1/'):
-            return self.v1(environ, start_response)
-        return self.v2(environ, start_response)
-
-
 def load_app():
     # Build the WSGI app
     cfg_file = None
@@ -130,16 +106,16 @@ def build_server():
     # Create the WSGI server and start it
     host, port = cfg.CONF.api.host, cfg.CONF.api.port
 
-    LOG.info(_('Starting server in PID %s') % os.getpid())
-    LOG.info(_("Configuration:"))
+    LOG.info(_LI('Starting server in PID %s') % os.getpid())
+    LOG.info(_LI("Configuration:"))
     cfg.CONF.log_opt_values(LOG, logging.INFO)
 
     if host == '0.0.0.0':
-        LOG.info(_(
+        LOG.info(_LI(
             'serving on 0.0.0.0:%(sport)s, view at http://127.0.0.1:%(vport)s')
             % ({'sport': port, 'vport': port}))
     else:
-        LOG.info(_("serving on http://%(host)s:%(port)s") % (
+        LOG.info(_LI("serving on http://%(host)s:%(port)s") % (
                  {'host': host, 'port': port}))
 
     serving.run_simple(cfg.CONF.api.host, cfg.CONF.api.port,
@@ -147,4 +123,4 @@ def build_server():
 
 
 def app_factory(global_config, **local_conf):
-    return VersionSelectorApplication()
+    return setup_app()
