@@ -13,6 +13,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from itertools import chain
 import socket
 
 import msgpack
@@ -24,8 +25,8 @@ from oslo_utils import netutils
 from oslo_utils import units
 
 from ceilometer import dispatcher
-from ceilometer import messaging
 from ceilometer.i18n import _, _LE
+from ceilometer import messaging
 from ceilometer import utils
 
 OPTS = [
@@ -33,29 +34,20 @@ OPTS = [
                default='0.0.0.0',
                help='Address to which the UDP socket is bound. Set to '
                'an empty string to disable.'),
-    cfg.IntOpt('udp_port',
-               default=4952,
-               min=1, max=65535,
-               help='Port to which the UDP socket is bound.'),
-    cfg.BoolOpt('requeue_sample_on_dispatcher_error',
-                default=False,
-                help='Requeue the sample on the collector sample queue '
-                'when the collector fails to dispatch it. This is only valid '
-                'if the sample come from the notifier publisher.'),
-    cfg.BoolOpt('requeue_event_on_dispatcher_error',
-                default=False,
-                help='Requeue the event on the collector event queue '
-                'when the collector fails to dispatch it.'),
-    cfg.BoolOpt('enable_rpc',
-                default=False,
-                help='Enable the RPC functionality of collector. This '
-                'functionality is now deprecated in favour of notifier '
-                'publisher and queues.')
+    cfg.PortOpt('udp_port',
+                default=4952,
+                help='Port to which the UDP socket is bound.'),
+    cfg.IntOpt('batch_size',
+               default=1,
+               help='Number of notification messages to wait before '
+               'dispatching them'),
+    cfg.IntOpt('batch_timeout',
+               default=None,
+               help='Number of seconds to wait before dispatching samples'
+               'when batch_size is not reached (None means indefinitely)'),
 ]
 
 cfg.CONF.register_opts(OPTS, group="collector")
-cfg.CONF.import_opt('metering_topic', 'ceilometer.publisher.messaging',
-                    group='publisher_rpc')
 cfg.CONF.import_opt('metering_topic', 'ceilometer.publisher.messaging',
                     group='publisher_notifier')
 cfg.CONF.import_opt('event_topic', 'ceilometer.publisher.messaging',
@@ -72,8 +64,8 @@ class CollectorService(os_service.Service):
     def start(self):
         """Bind the UDP socket and handle incoming data."""
         # ensure dispatcher is configured before starting other services
-        self.dispatcher_manager = dispatcher.load_dispatcher_manager()
-        self.rpc_server = None
+        dispatcher_managers = dispatcher.load_dispatcher_manager()
+        (self.meter_manager, self.event_manager) = dispatcher_managers
         self.sample_listener = None
         self.event_listener = None
         super(CollectorService, self).start()
@@ -83,34 +75,30 @@ class CollectorService(os_service.Service):
 
         transport = messaging.get_transport(optional=True)
         if transport:
-            if cfg.CONF.collector.enable_rpc:
-                LOG.warning('RPC collector is deprecated in favour of queues. '
-                            'Please switch to notifier publisher.')
-                self.rpc_server = messaging.get_rpc_server(
-                    transport, cfg.CONF.publisher_rpc.metering_topic, self)
+            if list(self.meter_manager):
+                sample_target = oslo_messaging.Target(
+                    topic=cfg.CONF.publisher_notifier.metering_topic)
+                self.sample_listener = (
+                    messaging.get_batch_notification_listener(
+                        transport, [sample_target],
+                        [SampleEndpoint(self.meter_manager)],
+                        allow_requeue=True,
+                        batch_size=cfg.CONF.collector.batch_size,
+                        batch_timeout=cfg.CONF.collector.batch_timeout))
+                self.sample_listener.start()
 
-            sample_target = oslo_messaging.Target(
-                topic=cfg.CONF.publisher_notifier.metering_topic)
-            self.sample_listener = messaging.get_notification_listener(
-                transport, [sample_target],
-                [SampleEndpoint(self.dispatcher_manager)],
-                allow_requeue=(cfg.CONF.collector.
-                               requeue_sample_on_dispatcher_error))
-
-            if cfg.CONF.notification.store_events:
+            if cfg.CONF.notification.store_events and list(self.event_manager):
                 event_target = oslo_messaging.Target(
                     topic=cfg.CONF.publisher_notifier.event_topic)
-                self.event_listener = messaging.get_notification_listener(
-                    transport, [event_target],
-                    [EventEndpoint(self.dispatcher_manager)],
-                    allow_requeue=(cfg.CONF.collector.
-                                   requeue_event_on_dispatcher_error))
+                self.event_listener = (
+                    messaging.get_batch_notification_listener(
+                        transport, [event_target],
+                        [EventEndpoint(self.event_manager)],
+                        allow_requeue=True,
+                        batch_size=cfg.CONF.collector.batch_size,
+                        batch_timeout=cfg.CONF.collector.batch_timeout))
                 self.event_listener.start()
 
-            if cfg.CONF.collector.enable_rpc:
-                self.rpc_server.start()
-            self.sample_listener.start()
-
             if not cfg.CONF.collector.udp_address:
                 # Add a dummy thread to have wait() working
                 self.tg.add_timer(604800, lambda: None)
@@ -132,19 +120,17 @@ class CollectorService(os_service.Service):
             try:
                 sample = msgpack.loads(data, encoding='utf-8')
             except Exception:
-                LOG.warn(_("UDP: Cannot decode data sent by %s"), source)
+                LOG.warning(_("UDP: Cannot decode data sent by %s"), source)
             else:
                 try:
                     LOG.debug("UDP: Storing %s", sample)
-                    self.dispatcher_manager.map_method('record_metering_data',
-                                                       sample)
+                    self.meter_manager.map_method('record_metering_data',
+                                                  sample)
                 except Exception:
                     LOG.exception(_("UDP: Unable to store meter"))
 
     def stop(self):
         self.udp_run = False
-        if cfg.CONF.collector.enable_rpc and self.rpc_server:
-            self.rpc_server.stop()
         if self.sample_listener:
             utils.kill_listeners([self.sample_listener])
         if self.event_listener:
@@ -157,45 +143,33 @@ class CollectorService(os_service.Service):
         When the notification messages are re-published through the
         RPC publisher, this method receives them for processing.
         """
-        self.dispatcher_manager.map_method('record_metering_data', data=data)
+        self.meter_manager.map_method('record_metering_data', data=data)
 
 
 class CollectorEndpoint(object):
-    def __init__(self, dispatcher_manager, requeue_on_error):
+    def __init__(self, dispatcher_manager):
         self.dispatcher_manager = dispatcher_manager
-        self.requeue_on_error = requeue_on_error
 
-    def sample(self, ctxt, publisher_id, event_type, payload, metadata):
+    def sample(self, messages):
         """RPC endpoint for notification messages
 
         When another service sends a notification over the message
         bus, this method receives it.
         """
+        samples = list(chain.from_iterable(m["payload"] for m in messages))
         try:
-            self.dispatcher_manager.map_method(self.method, payload)
+            self.dispatcher_manager.map_method(self.method, samples)
         except Exception:
-            if self.requeue_on_error:
-                LOG.exception(_LE("Dispatcher failed to handle the %s, "
-                                  "requeue it."), self.ep_type)
-                return oslo_messaging.NotificationResult.REQUEUE
-            raise
+            LOG.exception(_LE("Dispatcher failed to handle the %s, "
+                              "requeue it."), self.ep_type)
+            return oslo_messaging.NotificationResult.REQUEUE
 
 
 class SampleEndpoint(CollectorEndpoint):
     method = 'record_metering_data'
     ep_type = 'sample'
 
-    def __init__(self, dispatcher_manager):
-        super(SampleEndpoint, self).__init__(
-            dispatcher_manager,
-            cfg.CONF.collector.requeue_sample_on_dispatcher_error)
-
 
 class EventEndpoint(CollectorEndpoint):
     method = 'record_events'
     ep_type = 'event'
-
-    def __init__(self, dispatcher_manager):
-        super(EventEndpoint, self).__init__(
-            dispatcher_manager,
-            cfg.CONF.collector.requeue_event_on_dispatcher_error)
