@@ -32,10 +32,9 @@ OPTS = [
     cfg.StrOpt('host_ip',
                default='',
                help='IP address of the VMware vSphere host.'),
-    cfg.IntOpt('host_port',
-               default=443,
-               min=1, max=65535,
-               help='Port of the VMware vSphere host.'),
+    cfg.PortOpt('host_port',
+                default=443,
+                help='Port of the VMware vSphere host.'),
     cfg.StrOpt('host_username',
                default='',
                help='Username of VMware vSphere.'),
