@@ -18,7 +18,6 @@
 """
 
 from oslo_config import cfg
-from oslo_log import log
 import oslo_messaging
 
 from ceilometer.agent import plugin_base
@@ -27,14 +26,11 @@ from ceilometer import sample
 OPTS = [
     cfg.StrOpt('neutron_control_exchange',
                default='neutron',
-               help="Exchange name for Neutron notifications.",
-               deprecated_name='quantum_control_exchange'),
+               help="Exchange name for Neutron notifications."),
 ]
 
 cfg.CONF.register_opts(OPTS)
 
-LOG = log.getLogger(__name__)
-
 
 class NetworkNotificationBase(plugin_base.NotificationBase):
 
