@@ -12,17 +12,22 @@
 # under the License.
 
 import functools
+import logging
 
 import novaclient
 from novaclient import client as nova_client
 from oslo_config import cfg
 from oslo_log import log
 
+from ceilometer import keystone_client
 
 OPTS = [
     cfg.BoolOpt('nova_http_log_debug',
                 default=False,
-                help='Allow novaclient\'s debug log output.'),
+                # Added in Mikita
+                deprecated_for_removal=True,
+                help=('Allow novaclient\'s debug log output. '
+                      '(Use default_log_levels instead)')),
 ]
 
 SERVICE_OPTS = [
@@ -34,7 +39,7 @@ SERVICE_OPTS = [
 cfg.CONF.register_opts(OPTS)
 cfg.CONF.register_opts(SERVICE_OPTS, group='service_types')
 cfg.CONF.import_opt('http_timeout', 'ceilometer.service')
-cfg.CONF.import_group('service_credentials', 'ceilometer.service')
+cfg.CONF.import_group('service_credentials', 'ceilometer.keystone_client')
 
 LOG = log.getLogger(__name__)
 
@@ -55,26 +60,28 @@ def logged(func):
 class Client(object):
     """A client which gets information via python-novaclient."""
 
-    def __init__(self, bypass_url=None, auth_token=None):
+    def __init__(self, endpoint_override=None, auth=None):
         """Initialize a nova client object."""
         conf = cfg.CONF.service_credentials
-        tenant = conf.os_tenant_id or conf.os_tenant_name
+
+        logger = None
+        if cfg.CONF.nova_http_log_debug:
+            logger = logging.getLogger("novaclient-debug")
+            logger.setLevel(log.DEBUG)
+
         self.nova_client = nova_client.Client(
             version=2,
-            username=conf.os_username,
-            api_key=conf.os_password,
-            project_id=tenant,
-            auth_url=conf.os_auth_url,
-            auth_token=auth_token,
-            region_name=conf.os_region_name,
-            endpoint_type=conf.os_endpoint_type,
+            session=keystone_client.get_session(),
+
+            # nova adapter options
+            region_name=conf.region_name,
+            interface=conf.interface,
             service_type=cfg.CONF.service_types.nova,
-            bypass_url=bypass_url,
-            cacert=conf.os_cacert,
-            insecure=conf.insecure,
-            timeout=cfg.CONF.http_timeout,
-            http_log_debug=cfg.CONF.nova_http_log_debug,
-            no_cache=True)
+
+            # keystone adapter options
+            endpoint_override=endpoint_override,
+            auth=auth,
+            logger=logger)
 
     def _with_flavor_and_image(self, instances):
         flavor_cache = {}
