@@ -13,14 +13,12 @@
 # under the License.
 import itertools
 
+from keystoneauth1 import loading
+
 import ceilometer.agent.manager
-import ceilometer.alarm.notifier.rest
-import ceilometer.alarm.rpc
-import ceilometer.alarm.service
 import ceilometer.api
 import ceilometer.api.app
-import ceilometer.api.controllers.v2.alarms
-import ceilometer.cmd.eventlet.polling
+import ceilometer.cmd.polling
 import ceilometer.collector
 import ceilometer.compute.discovery
 import ceilometer.compute.notifications
@@ -40,6 +38,7 @@ import ceilometer.image.glance
 import ceilometer.ipmi.notifications.ironic
 import ceilometer.ipmi.platform.intel_node_manager
 import ceilometer.ipmi.pollsters
+import ceilometer.keystone_client
 import ceilometer.meter.notifications
 import ceilometer.middleware
 import ceilometer.network.notifications
@@ -62,7 +61,7 @@ def list_opts():
         ('DEFAULT',
          itertools.chain(ceilometer.agent.manager.OPTS,
                          ceilometer.api.app.OPTS,
-                         ceilometer.cmd.eventlet.polling.CLI_OPTS,
+                         ceilometer.cmd.polling.CLI_OPTS,
                          ceilometer.compute.notifications.OPTS,
                          ceilometer.compute.util.OPTS,
                          ceilometer.compute.virt.inspector.OPTS,
@@ -78,13 +77,8 @@ def list_opts():
                          ceilometer.sample.OPTS,
                          ceilometer.service.OPTS,
                          ceilometer.storage.OLD_OPTS,
+                         ceilometer.storage.CLI_OPTS,
                          ceilometer.utils.OPTS,)),
-        ('alarm',
-         itertools.chain(ceilometer.alarm.notifier.rest.OPTS,
-                         ceilometer.alarm.service.OPTS,
-                         ceilometer.alarm.rpc.OPTS,
-                         ceilometer.alarm.evaluator.gnocchi.OPTS,
-                         ceilometer.api.controllers.v2.alarms.ALARM_API_OPTS)),
         ('api',
          itertools.chain(ceilometer.api.OPTS,
                          ceilometer.api.app.API_OPTS,
@@ -112,9 +106,16 @@ def list_opts():
         ('polling', ceilometer.agent.manager.OPTS),
         ('publisher', ceilometer.publisher.utils.OPTS),
         ('publisher_notifier', ceilometer.publisher.messaging.NOTIFIER_OPTS),
-        ('publisher_rpc', ceilometer.publisher.messaging.RPC_OPTS),
         ('rgw_admin_credentials', ceilometer.objectstore.rgw.CREDENTIAL_OPTS),
-        ('service_credentials', ceilometer.service.CLI_OPTS),
+        # NOTE(sileht): the configuration file contains only the options
+        # for the password plugin that handles keystone v2 and v3 API
+        # with discovery. But other options are possible.
+        # Also, the default loaded plugin is password-ceilometer-legacy for
+        # backward compatibily
+        ('service_credentials', (
+            ceilometer.keystone_client.CLI_OPTS +
+            loading.get_auth_common_conf_options() +
+            loading.get_auth_plugin_conf_options('password'))),
         ('service_types',
          itertools.chain(ceilometer.energy.kwapi.SERVICE_OPTS,
                          ceilometer.image.glance.SERVICE_OPTS,
@@ -122,6 +123,7 @@ def list_opts():
                          ceilometer.nova_client.SERVICE_OPTS,
                          ceilometer.objectstore.rgw.SERVICE_OPTS,
                          ceilometer.objectstore.swift.SERVICE_OPTS,)),
+        ('storage', ceilometer.dispatcher.STORAGE_OPTS),
         ('vmware', ceilometer.compute.virt.vmware.inspector.OPTS),
         ('xenapi', ceilometer.compute.virt.xenapi.inspector.OPTS),
     ]
