@@ -49,12 +49,11 @@ def iter_period(start, end, period):
 def _handle_sort_key(model_name, sort_key=None):
     """Generate sort keys according to the passed in sort key from user.
 
-    :param model_name: Database model name be query.(alarm, meter, etc.)
+    :param model_name: Database model name be query.(meter, etc.)
     :param sort_key: sort key passed from user.
     return: sort keys list
     """
-    sort_keys_extra = {'alarm': ['name', 'user_id', 'project_id'],
-                       'meter': ['user_id', 'project_id'],
+    sort_keys_extra = {'meter': ['user_id', 'project_id'],
                        'resource': ['user_id', 'project_id', 'timestamp'],
                        }
 
@@ -195,7 +194,7 @@ class Connection(object):
 
     @staticmethod
     def get_meters(user=None, project=None, resource=None, source=None,
-                   metaquery=None, limit=None):
+                   metaquery=None, limit=None, unique=False):
         """Return an iterable of model.Meter instances.
 
         Iterable items containing meter information.
@@ -205,6 +204,7 @@ class Connection(object):
         :param source: Optional source filter.
         :param metaquery: Optional dict with metadata to match on.
         :param limit: Maximum number of results to return.
+        :param unique: If set to true, return only unique meter information.
         """
         raise ceilometer.NotImplementedError('Meters not implemented')
 
