@@ -385,7 +385,7 @@ def deserialize_entry(entry, get_raw_meta=True):
     else:
         metadata = metadata_flattened
 
-    return flatten_result, sources, meters, metadata
+    return flatten_result, meters, metadata
 
 
 def serialize_entry(data=None, **kwargs):
@@ -471,9 +471,9 @@ def create_tables(conn, tables, column_families):
                               separator=conn.table_prefix_separator,
                               table_name=table))
 
-            LOG.warn(_("Cannot create table %(table_name)s   "
-                       "it already exists. Ignoring error")
-                     % {'table_name': table})
+            LOG.warning(_("Cannot create table %(table_name)s   "
+                        "it already exists. Ignoring error")
+                        % {'table_name': table})
 
 
 def quote(s, *args):
