@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-#
 # Copyright 2012 New Dream Network (DreamHost)
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -18,7 +16,6 @@
 import functools
 import os.path
 
-import eventlet
 import oslo_messaging.conffixture
 from oslo_utils import timeutils
 from oslotest import base
@@ -39,10 +36,6 @@ class BaseTestCase(base.BaseTestCase):
             exchange = 'ceilometer'
         conf.set_override("control_exchange", exchange)
 
-        # oslo.messaging fake driver needs time and thread
-        # to be patched, otherwise there are chances of deadlocks
-        eventlet.monkey_patch(time=True, thread=True)
-
         # NOTE(sileht): Ensure a new oslo.messaging driver is loaded
         # between each tests
         self.transport = messaging.get_transport("fake://", cache=False)
