@@ -30,8 +30,7 @@ HEADERS = {"X-Roles": "admin",
            "X-Project-Id": PROJ_ID}
 
 
-class EventTestBase(v2.FunctionalTest,
-                    tests_db.MixinTestsWithBackendScenarios):
+class EventTestBase(v2.FunctionalTest):
 
     def setUp(self):
         super(EventTestBase, self).setUp()
@@ -192,7 +191,6 @@ class TestEventAPI(EventTestBase):
         self.assertEqual('Foo', data[0]['event_type'])
 
     def test_get_events_filter_trait_empty_type(self):
-        return
         data = self.get_json(self.PATH, headers=HEADERS,
                              q=[{'field': 'trait_A',
                                  'value': 'my_Foo_text',
@@ -219,7 +217,7 @@ class TestEventAPI(EventTestBase):
                                  'op': 'whats-up'}],
                              expect_errors=True)
         self.assertEqual(400, resp.status_code)
-        self.assertEqual("operator whats-up is not supported. the "
+        self.assertEqual("Operator whats-up is not supported. The "
                          "supported operators are: (\'lt\', \'le\', "
                          "\'eq\', \'ne\', \'ge\', \'gt\')",
                          resp.json['error_message']['faultstring'])
@@ -467,8 +465,7 @@ class TestEventAPI(EventTestBase):
                               'op': 'el'}])
 
 
-class AclRestrictedEventTestBase(v2.FunctionalTest,
-                                 tests_db.MixinTestsWithBackendScenarios):
+class AclRestrictedEventTestBase(v2.FunctionalTest):
 
     def setUp(self):
         super(AclRestrictedEventTestBase, self).setUp()
@@ -596,8 +593,7 @@ class AclRestrictedEventTestBase(v2.FunctionalTest,
         self.assertEqual(0, len(data))
 
 
-class EventRestrictionTestBase(v2.FunctionalTest,
-                               tests_db.MixinTestsWithBackendScenarios):
+class EventRestrictionTestBase(v2.FunctionalTest):
 
     def setUp(self):
         super(EventRestrictionTestBase, self).setUp()
