@@ -22,19 +22,22 @@ from unittest import case
 import uuid
 
 from gabbi import fixture
+from oslo_config import cfg
 from oslo_config import fixture as fixture_config
 from oslo_policy import opts
+from oslo_utils import fileutils
+import six
+from six.moves.urllib import parse as urlparse
 
 from ceilometer.event.storage import models
 from ceilometer.publisher import utils
 from ceilometer import sample
 from ceilometer import storage
 
-
 # TODO(chdent): For now only MongoDB is supported, because of easy
 # database name handling and intentional focus on the API, not the
 # data store.
-ENGINES = ['MONGODB']
+ENGINES = ['mongodb']
 
 
 class ConfigFixture(fixture.GabbiFixture):
@@ -46,15 +49,15 @@ class ConfigFixture(fixture.GabbiFixture):
         self.conf = None
 
         # Determine the database connection.
-        db_url = None
-        for engine in ENGINES:
-            try:
-                db_url = os.environ['CEILOMETER_TEST_%s_URL' % engine]
-            except KeyError:
-                pass
-        if db_url is None:
+        db_url = os.environ.get('OVERTEST_URL', "sqlite://").replace(
+            "mysql://", "mysql+pymysql://")
+        if not db_url:
             raise case.SkipTest('No database connection configured')
 
+        engine = urlparse.urlparse(db_url).scheme
+        if engine not in ENGINES:
+            raise case.SkipTest('Database engine not supported')
+
         conf = fixture_config.Config().conf
         self.conf = conf
         self.conf([], project='ceilometer', validate_default_values=True)
@@ -62,19 +65,30 @@ class ConfigFixture(fixture.GabbiFixture):
         conf.import_group('api', 'ceilometer.api.controllers.v2.root')
         conf.import_opt('store_events', 'ceilometer.notification',
                         group='notification')
-        conf.set_override('policy_file',
-                          os.path.abspath('etc/ceilometer/policy.json'),
+
+        content = ('{"default": ""}')
+        if six.PY3:
+            content = content.encode('utf-8')
+        self.tempfile = fileutils.write_to_tempfile(content=content,
+                                                    prefix='policy',
+                                                    suffix='.json')
+
+        conf.set_override("policy_file", self.tempfile,
                           group='oslo_policy')
+        conf.set_override(
+            'api_paste_config',
+            os.path.abspath(
+                'ceilometer/tests/functional/gabbi/gabbi_paste.ini')
+        )
 
         # A special pipeline is required to use the direct publisher.
         conf.set_override('pipeline_cfg_file',
-                          'etc/ceilometer/gabbi_pipeline.yaml')
+                          'ceilometer/tests/functional/gabbi_pipeline.yaml')
 
         database_name = '%s-%s' % (db_url, str(uuid.uuid4()))
         conf.set_override('connection', database_name, group='database')
         conf.set_override('metering_connection', '', group='database')
         conf.set_override('event_connection', '', group='database')
-        conf.set_override('alarm_connection', '', group='database')
 
         conf.set_override('pecan_debug', True, group='api')
         conf.set_override('gnocchi_is_enabled', False, group='api')
@@ -150,3 +164,24 @@ class EventDataFixture(fixture.GabbiFixture):
     def stop_fixture(self):
         """Destroy the events."""
         self.conn.db.event.remove({'event_type': '/^cookies_/'})
+
+
+class CORSConfigFixture(fixture.GabbiFixture):
+    """Inject mock configuration for the CORS middleware."""
+
+    def start_fixture(self):
+        # Here we monkeypatch GroupAttr.__getattr__, necessary because the
+        # paste.ini method of initializing this middleware creates its own
+        # ConfigOpts instance, bypassing the regular config fixture.
+
+        def _mock_getattr(instance, key):
+            if key != 'allowed_origin':
+                return self._original_call_method(instance, key)
+            return "http://valid.example.com"
+
+        self._original_call_method = cfg.ConfigOpts.GroupAttr.__getattr__
+        cfg.ConfigOpts.GroupAttr.__getattr__ = _mock_getattr
+
+    def stop_fixture(self):
+        """Remove the monkeypatch."""
+        cfg.ConfigOpts.GroupAttr.__getattr__ = self._original_call_method
