@@ -30,5 +30,5 @@ def load_tests(loader, tests, pattern):
     test_dir = os.path.join(os.path.dirname(__file__), TESTS_DIR)
     return driver.build_tests(test_dir, loader, host=None,
                               prefix='/telemetry',
-                              intercept=app.VersionSelectorApplication,
+                              intercept=app.setup_app,
                               fixture_module=fixture_module)
