@@ -156,10 +156,8 @@ class TestNotification(tests_base.BaseTestCase):
                          self.srv.listeners[0].dispatcher.endpoints[0])
 
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
-    @mock.patch.object(oslo_messaging.MessageHandlingServer, 'start',
-                       mock.MagicMock())
-    @mock.patch('ceilometer.event.endpoint.EventsNotificationEndpoint')
-    def test_unique_consumers(self, fake_event_endpoint_class):
+    @mock.patch('oslo_messaging.get_batch_notification_listener')
+    def test_unique_consumers(self, mock_listener):
 
         def fake_get_notifications_manager_dup_targets(pm):
             plugin = instance.Instance(pm)
@@ -171,7 +169,10 @@ class TestNotification(tests_base.BaseTestCase):
                                '_get_notifications_manager') as get_nm:
             get_nm.side_effect = fake_get_notifications_manager_dup_targets
             self.srv.start()
-            self.assertEqual(1, len(self.srv.listeners[0].dispatcher.targets))
+            self.assertEqual(1, len(mock_listener.call_args_list))
+            args, kwargs = mock_listener.call_args
+            self.assertEqual(1, len(args[1]))
+            self.assertIsInstance(args[1][0], oslo_messaging.Target)
 
 
 class BaseRealNotification(tests_base.BaseTestCase):
@@ -257,7 +258,6 @@ class BaseRealNotification(tests_base.BaseTestCase):
             if (len(self.publisher.samples) >= self.expected_samples and
                     len(self.publisher.events) >= self.expected_events):
                 break
-        self.assertNotEqual(self.srv.listeners, self.srv.pipeline_listeners)
         self.srv.stop()
 
         resources = list(set(s.resource_id for s in self.publisher.samples))
@@ -387,31 +387,71 @@ class TestRealNotificationHA(BaseRealNotification):
         fake_publisher_cls.return_value = self.publisher
         self._check_notification_service()
 
-    def test_reset_listeners_on_refresh(self):
+    @mock.patch('oslo_messaging.get_batch_notification_listener')
+    def test_reset_listener_on_refresh(self, mock_listener):
+        mock_listener.side_effect = [
+            mock.MagicMock(),  # main listener
+            mock.MagicMock(),  # pipeline listener
+            mock.MagicMock(),  # refresh pipeline listener
+        ]
+
         self.srv.start()
-        listeners = self.srv.pipeline_listeners
-        self.assertEqual(20, len(listeners))
-        self.srv._configure_pipeline_listeners()
-        self.assertEqual(20, len(self.srv.pipeline_listeners))
-        for listener in listeners:
-            self.assertNotIn(listeners, set(self.srv.pipeline_listeners))
+
+        def _check_listener_targets():
+            args, kwargs = mock_listener.call_args
+            self.assertEqual(20, len(args[1]))
+            self.assertIsInstance(args[1][0], oslo_messaging.Target)
+
+        _check_listener_targets()
+
+        listener = self.srv.pipeline_listener
+        self.srv._configure_pipeline_listener()
+        self.assertIsNot(listener, self.srv.pipeline_listener)
+        _check_listener_targets()
+
         self.srv.stop()
 
-    def test_retain_common_listeners_on_refresh(self):
+    @mock.patch('oslo_messaging.get_batch_notification_listener')
+    def test_retain_common_targets_on_refresh(self, mock_listener):
         with mock.patch('ceilometer.coordination.PartitionCoordinator'
                         '.extract_my_subset', return_value=[1, 2]):
             self.srv.start()
-        self.assertEqual(4, len(self.srv.pipeline_listeners))
-        listeners = [listener for listener in self.srv.pipeline_listeners]
+        listened_before = [target.topic for target in
+                           mock_listener.call_args[0][1]]
+        self.assertEqual(4, len(listened_before))
         with mock.patch('ceilometer.coordination.PartitionCoordinator'
                         '.extract_my_subset', return_value=[1, 3]):
             self.srv._refresh_agent(None)
-        self.assertEqual(4, len(self.srv.pipeline_listeners))
-        for listener in listeners:
-            if listener.dispatcher.targets[0].topic.endswith('1'):
-                self.assertIn(listener, set(self.srv.pipeline_listeners))
-            else:
-                self.assertNotIn(listener, set(self.srv.pipeline_listeners))
+        listened_after = [target.topic for target in
+                          mock_listener.call_args[0][1]]
+        self.assertEqual(4, len(listened_after))
+        common = set(listened_before) & set(listened_after)
+        for topic in common:
+            self.assertTrue(topic.endswith('1'))
+        self.srv.stop()
+
+    @mock.patch('oslo_messaging.get_batch_notification_listener')
+    def test_notify_to_relevant_endpoint(self, mock_listener):
+        self.srv.start()
+
+        targets = mock_listener.call_args[0][1]
+        self.assertIsNotEmpty(targets)
+
+        endpoints = {}
+        for endpoint in mock_listener.call_args[0][2]:
+            self.assertEqual(1, len(endpoint.publish_context.pipelines))
+            pipe = list(endpoint.publish_context.pipelines)[0]
+            endpoints[pipe.name] = endpoint
+
+        notifiers = []
+        notifiers.extend(self.srv.pipe_manager.transporters[0][2])
+        notifiers.extend(self.srv.event_pipe_manager.transporters[0][2])
+        for notifier in notifiers:
+            filter_rule = endpoints[notifier.publisher_id].filter_rule
+            self.assertEqual(True, filter_rule.match(None,
+                                                     notifier.publisher_id,
+                                                     None, None, None))
+
         self.srv.stop()
 
     @mock.patch('oslo_messaging.Notifier.sample')
