@@ -43,7 +43,7 @@ export AODH_SERVICE_URL=$(openstack catalog show alarming -c endpoints -f value
 export GNOCCHI_SERVICE_URL=$(openstack catalog show metric -c endpoints -f value | awk '/public/{print $2}')
 export HEAT_SERVICE_URL=$(openstack catalog show orchestration -c endpoints -f value | awk '/public/{print $2}')
 export NOVA_SERVICE_URL=$(openstack catalog show compute -c endpoints -f value | awk '/public/{print $2}')
-export GLANCE_IMAGE_NAME=$(openstack image list | awk '/ cirros.*uec /{print $4}')
+export GLANCE_IMAGE_NAME=$(openstack image list | awk '/ cirros.* /{print $4; exit}')
 export ADMIN_TOKEN=$(openstack token issue -c id -f value)
 
 # Run tests
@@ -55,6 +55,7 @@ EXIT_CODE=$?
 
 echo "* Message queue status:"
 sudo rabbitmqctl list_queues | grep -e \\.sample -e \\.info
+sudo rabbitmqctl list_consumers
 
 if [ $EXIT_CODE -ne 0 ] ; then
     set +x
