@@ -23,8 +23,8 @@ from oslotest import base
 from oslotest import mockpatch
 import wsme
 
-from ceilometer.alarm.storage import base as alarm_storage_base
 from ceilometer.api.controllers.v2 import base as v2_base
+from ceilometer.api.controllers.v2 import events
 from ceilometer.api.controllers.v2 import meters
 from ceilometer.api.controllers.v2 import utils
 from ceilometer import storage
@@ -37,6 +37,10 @@ class TestQuery(base.BaseTestCase):
         super(TestQuery, self).setUp()
         self.useFixture(fixtures.MonkeyPatch(
             'pecan.response', mock.MagicMock()))
+        self.useFixture(mockpatch.Patch('ceilometer.api.controllers.v2.events'
+                                        '._build_rbac_query_filters',
+                                        return_value={'t_filter': [],
+                                                      'admin_proj': None}))
 
     def test_get_value_as_type_with_integer(self):
         query = v2_base.Query(field='metadata.size',
@@ -154,6 +158,15 @@ class TestQuery(base.BaseTestCase):
         expected = value
         self.assertEqual(expected, query._get_value_as_type())
 
+    def test_event_query_to_event_filter_with_bad_op(self):
+        # bug 1511592
+        query = v2_base.Query(field='event_type',
+                              op='ne',
+                              value='compute.instance.create.end',
+                              type='string')
+        self.assertRaises(v2_base.ClientSideError,
+                          events._event_query_to_event_filter, [query])
+
 
 class TestValidateGroupByFields(base.BaseTestCase):
 
@@ -317,7 +330,7 @@ class TestQueryToKwArgs(tests_base.BaseTestCase):
             request.headers.return_value = {'X-ProjectId': 'foobar'}
             kwargs = utils.query_to_kwargs(queries,
                                            storage.SampleFilter.__init__)
-            self.assertFalse('self' in kwargs)
+            self.assertNotIn('self', kwargs)
 
     def test_sample_filter_translation(self):
         queries = [v2_base.Query(field=f,
@@ -345,21 +358,6 @@ class TestQueryToKwArgs(tests_base.BaseTestCase):
                                              'invalid timestamp format')
         self.assertEqual(str(expected_exc), str(exc))
 
-    def test_get_alarm_changes_filter_valid_fields(self):
-        q = [v2_base.Query(field='abc',
-                           op='eq',
-                           value='abc')]
-        exc = self.assertRaises(
-            wsme.exc.UnknownArgument,
-            utils.query_to_kwargs, q,
-            alarm_storage_base.Connection.get_alarm_changes)
-        valid_keys = ['alarm_id', 'on_behalf_of', 'project', 'search_offset',
-                      'severity', 'timestamp', 'type', 'user']
-        msg = ("unrecognized field in query: %s, "
-               "valid keys: %s") % (q, valid_keys)
-        expected_exc = wsme.exc.UnknownArgument('abc', msg)
-        self.assertEqual(str(expected_exc), str(exc))
-
     def test_sample_filter_valid_fields(self):
         q = [v2_base.Query(field='abc',
                            op='eq',
@@ -381,7 +379,7 @@ class TestQueryToKwArgs(tests_base.BaseTestCase):
         exc = self.assertRaises(
             wsme.exc.UnknownArgument,
             utils.query_to_kwargs,
-            q, storage_base.Connection.get_meters, ['limit'])
+            q, storage_base.Connection.get_meters, ['limit', 'unique'])
         valid_keys = ['project', 'resource', 'source', 'user']
         msg = ("unrecognized field in query: %s, "
                "valid keys: %s") % (q, valid_keys)
@@ -402,18 +400,3 @@ class TestQueryToKwArgs(tests_base.BaseTestCase):
                "valid keys: %s") % (q, valid_keys)
         expected_exc = wsme.exc.UnknownArgument('abc', msg)
         self.assertEqual(str(expected_exc), str(exc))
-
-    def test_get_alarms_filter_valid_fields(self):
-        q = [v2_base.Query(field='abc',
-                           op='eq',
-                           value='abc')]
-        exc = self.assertRaises(
-            wsme.exc.UnknownArgument,
-            utils.query_to_kwargs, q,
-            alarm_storage_base.Connection.get_alarms)
-        valid_keys = ['alarm_id', 'enabled', 'meter', 'name',
-                      'project', 'severity', 'state', 'type', 'user']
-        msg = ("unrecognized field in query: %s, "
-               "valid keys: %s") % (q, valid_keys)
-        expected_exc = wsme.exc.UnknownArgument('abc', msg)
-        self.assertEqual(str(expected_exc), str(exc))
