@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-#
 # Copyright 2012 Red Hat, Inc
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -62,6 +60,17 @@ class TestLibvirtInspection(base.BaseTestCase):
             self.assertEqual(2, cpu_info.number)
             self.assertEqual(999999, cpu_info.time)
 
+    def test_inspect_cpus_with_domain_shutoff(self):
+        connection = self.inspector.connection
+        with mock.patch.object(connection, 'lookupByUUIDString',
+                               return_value=self.domain):
+            with mock.patch.object(self.domain, 'info',
+                                   return_value=(5, 0, 0,
+                                                 2, 999999)):
+                self.assertRaises(virt_inspector.InstanceShutOffException,
+                                  self.inspector.inspect_cpus,
+                                  self.instance)
+
     def test_inspect_vnics(self):
         dom_xml = """
              <domain type='kvm'>
@@ -341,25 +350,3 @@ class TestLibvirtInspectionWithError(base.BaseTestCase):
     def test_inspect_unknown_error(self):
         self.assertRaises(virt_inspector.InspectorException,
                           self.inspector.inspect_cpus, 'foo')
-
-
-class TestLibvirtInitWithError(base.BaseTestCase):
-
-    def setUp(self):
-        super(TestLibvirtInitWithError, self).setUp()
-        self.inspector = libvirt_inspector.LibvirtInspector()
-        libvirt_inspector.libvirt = mock.Mock()
-
-    @mock.patch('ceilometer.compute.virt.libvirt.inspector.'
-                'LibvirtInspector._get_connection',
-                mock.Mock(return_value=None))
-    def test_init_error(self):
-        self.assertRaises(virt_inspector.NoSanityException,
-                          self.inspector.check_sanity)
-
-    @mock.patch('ceilometer.compute.virt.libvirt.inspector.'
-                'LibvirtInspector._get_connection',
-                mock.Mock(side_effect=virt_inspector.NoDataException))
-    def test_init_exception(self):
-        self.assertRaises(virt_inspector.NoDataException,
-                          self.inspector.check_sanity)
